@@ -8,6 +8,10 @@ ________________________________________________________________________________
 
 from pyautoeasy import ScreenPoint
 
-bar = ScreenPoint(pos=(1189, 47))
-bar.double_click_here()
+sd = ScreenPoint(pos=(1140, 669))
+sd.click_here()
+
+
+asd = ScreenPoint(pos=(1089, 230))
+asd.click_here()
 
